#import "DragImageView.h"

@implementation DragImageView

- (id)init
{
	[super init];
	imgPath = nil;
	return self;
}

- (void)dealloc
{
	if(imgPath) [imgPath release];
	[super dealloc];
}

- (void)drawRect:(NSRect)aRect
{
	NSGraphicsContext *gc = [NSGraphicsContext currentContext];
	[gc setImageInterpolation:NSImageInterpolationHigh];
	[super drawRect:aRect];
}

- (NSDragOperation)draggingEntered:(id <NSDraggingInfo>)info
{
	NSArray *fileArr = [[info draggingPasteboard] propertyListForType:NSFilenamesPboardType];
	if([fileArr count] != 1) return NSDragOperationNone;
	
	BOOL isDir;
	[[NSFileManager defaultManager] fileExistsAtPath:[fileArr objectAtIndex:0] isDirectory:&isDir];
	if(isDir) return NSDragOperationNone;
	
	[[NSCursor _copyDragCursor] set];
	return NSDragOperationGeneric;
}

- (void)draggingExited:(id <NSDraggingInfo>)info
{
	[[NSCursor arrowCursor] set];
}

- (BOOL)performDragOperation:(id <NSDraggingInfo>)info
{
	NSString *path = [[[info draggingPasteboard] propertyListForType:NSFilenamesPboardType] objectAtIndex:0];
	NSImage *img = [[NSImage alloc] initByReferencingFile:path];
	if([img isValid]) {
		[self setImage:img];
		[img release];
		if(imgPath) [imgPath release];
		imgPath = [path retain];
		return YES;
	}
	else {
		[img release];
		if(imgPath) [imgPath release];
		imgPath = nil;
		return NO;
	}
}

- (void)concludeDragOperation:(id <NSDraggingInfo>)info
{
	
}

- (void)clearPath
{
	if(imgPath) [imgPath release];
	imgPath = nil;
}

- (void)setImgPath:(NSString *)path
{
	if(imgPath) [imgPath release];
	imgPath = [path retain];
}

- (NSString *)imgPath
{
	if(imgPath) return imgPath;
	else return @"";
}

@end
